@@ -1,12 +1,12 @@
-#!/bin/sh
+#!/bin/bash
 
 PATCHFILE=testpatch.diff
 
-if [ "${OSTYPE:-}" = "linux-gnu" ] ; then
+if [ $OSTYPE == "linux-gnu" ] ; then
     WINMERGE='/usr/bin/meld'
     EMACS=emacs
 else
-    WINMERGE='c:/Program Files (x86)/Meld/Meld.exe'
+    WINMERGE='/cygdrive/c/Program Files/KDiff3/kdiff3.exe'
     EMACS=emacs.bat
 fi
 
@@ -17,8 +17,7 @@ fi
 
 (cd res
     found=0
-    shopt -s nullglob
-    for test_case in *.txt *.ad[sb] ; do
+    for test_case in *.txt; do
 	diff=`diff ${test_case} ../ref/${test_case}`
 	if [ "$diff" != "" ]; then
             found=1
